Documentation
¶
Overview ¶
Package vault implements a koanf.Provider for Hashicorp Vault KV secrets engine and provides it to koanf to be parsed by a koanf.Parser.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Vault server address
Address string
// Vault static token
Token string
// Secret data path
Path string
// If FlatPaths is true, then the loaded configuration is not split into
// hierarchical maps based on the delimiter. The keys including the delimiter,
// eg: app.db.name stays as-is in the confmap.
FlatPaths bool
// Delim is the delimiter to use
// when specifying config key paths, for instance a . for `parent.child.key`
// or a / for `parent/child/key`.
Delim string
// Internal HTTP client timeout
Timeout time.Duration
// ExcludeMeta states whether the secret should be returned with its metadata.
// If ExcludeMeta is true, no metadata will be returned, and the data can be
// accessed as `k.String("key")`. If set to false, the value for data `key`
// and the metadata `version` can be accessed as `k.String("data.key")` and
// `k.Int("metadata.version")`.
ExcludeMeta bool
}
Click to show internal directories.
Click to hide internal directories.